# coding: utf-8
# **************************************************************************
# *
# * Authors: Scipion team
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 3 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

"""
@article{Wagner2019,
  title = "SPHIRE-crYOLO is a fast and accurate fully automated particle picker for cryo-EM",
  author = {Thorsten Wagner, Felipe Merino, Markus Stabrin},
  journal = "Communications Biology",
  volume = "2",
  number = "218",
  year = "2019",
  publisher = "Nature Publishing Group",
  doi = "https://doi.org/10.1038/s42003-019-0437-z",
  url = "https://www.nature.com/articles/s42003-019-0437-z",
}

@misc{thorsten_wagner_2019_3378300,
  author       = {Thorsten Wagner},
  title        = {MPI-Dortmund/sphire-janni: JANNI 0.0.5},
  month        = {aug},
  year         = 2019,
  publisher    = {Zenodo},
  version      = {v0.0.5},
  doi          = {https://doi.org/10.5281/zenodo.3378300}
}
"""